@@ -1,3 +1,4 @@
+import json
 from typing import TYPE_CHECKING, Any
 from flask_jwt_extended import create_access_token as jwt_create_access_token  # type: ignore
 from sqlalchemy.orm import Session
@@ -7,11 +8,12 @@ if TYPE_CHECKING:
 
 
 def create_access_token(user: "UserBase"):
-    return jwt_create_access_token(identity=[user.id, user.password])
+    return jwt_create_access_token(identity=json.dumps([user.id, user.password]))
 
 
 def get_user_id_by_jwt_identity(jwt_identity: Any):
-    if not isinstance(jwt_identity, (list, tuple)) or len(jwt_identity) != 2:  # type: ignore
+    jwt_identity = json.loads(jwt_identity)
+    if not isinstance(jwt_identity, list) or len(jwt_identity) != 2:  # type: ignore
         return None
     id, password = jwt_identity  # type: ignore
     if not isinstance(id, int) or not isinstance(password, str):
@@ -22,7 +24,8 @@ def get_user_id_by_jwt_identity(jwt_identity: Any):
 
 def get_user_by_jwt_identity(db_sess: Session, jwt_identity: Any):
     from .data.user import get_user_table
-    if not isinstance(jwt_identity, (list, tuple)) or len(jwt_identity) != 2:  # type: ignore
+    jwt_identity = json.loads(jwt_identity)
+    if not isinstance(jwt_identity, list) or len(jwt_identity) != 2:  # type: ignore
         return None
     id, password = jwt_identity  # type: ignore
     if not isinstance(id, int) or not isinstance(password, str):
