@@ -1,5 +1,6 @@
+from typing import Any
 from flask import jsonify
 
 
-def jsonify_list(items, field_get_dict="get_dict"):
+def jsonify_list(items: list[Any], field_get_dict: str = "get_dict"):
     return jsonify(list(map(lambda x: getattr(x, field_get_dict)(), items)))
